@@ -30,6 +30,7 @@ sntdf			= lambda snt: pd.DataFrame( requests.get(f'http://yulk.net/parse~{snt}')
 scalar			= lambda df: df.values[0, 0] if len(df) > 0 else None  # scalar
 sql				= lambda q: duckdb.sql(q).fetchdf()
 loadsql			= lambda name: duckdb.execute(requests.get(f'http://file.yulk.net/sql/{name}.sql').text)
+pd.DataFrame.sort	= lambda self, col=-1: self.sort_values(by=col if isinstance(col, str) else self.columns[col], ascending=False) # more in file.yulk.net/py/df.py
 
 def loadpy(name):  ## load duck/yulk..., from pyexec/*.py 
 	try:
@@ -70,6 +71,9 @@ for name in ('util','yulkinit'):
 		loadsql(name) # add try later , online yulkinit.sql file must exist
 	except Exception as e:
 		print (">>failed to loadsql:",e, name)
+for name in ('dobjnv','dobjvn','amodan','amodna','advmodvd','advmoddv','nsubjvn','nsubjnv','lempos'): 
+	duckdb.execute(f"CREATE OR REPLACE VIEW en.{name} AS (SELECT key, label, en AS cnt, keyness FROM '{root}/par/{name}.parquet' WHERE en > 0 ORDER BY cnt desc)")
+	duckdb.execute(f"CREATE OR REPLACE VIEW cn.{name} AS (SELECT key, label, cn AS cnt, keyness FROM '{root}/par/{name}.parquet' WHERE cn > 0 ORDER BY cnt desc)")
 
 def parse(snt): 
 	import spacy
